load_module

Function load_module 

pub fn load_module(path: &Path, strict: bool) -> Result<Module, Error>
Reads the directory at the given path and attempts to interpret it as a Terraform module.

Arguments

  • path - Path to the directory containing the Terraform configuration
  • strict - Whether to immediately return an error if a file in the directory cannot be parsed